# boaHancock
![Logo](.github/boa.jpg)

This is project to generate starter template for create moduls or library in python

## Feature

- create folder `poject_name` and `test`.
- create file `LICENSE` from license list selected.
- create file `README.md` from templates .
- make file `setup.py` configured to deployment.
- make file `.gitignore` for configure to deployment in github.
- Membuat file `__init__.py` di dalam folder `src` untuk modul Python.
- provide license like a MIT, Apache, BSD-3-Clause, e, g.

## Instalation
```bash
git clone https://github.com/Anammkh/boaHancock.git
cd boaHancock/boaHancock/
python generator.py
```
## or using pip
```
pip install boaHancock

boaHancock
```

## 
